@@ -1,12 +1,11 @@
 /*****************************************************************************
- * Secure Locate v2.1                                                        *
- * October 19, 1999                                                          *
+ * Secure Locate v2.2                                                        *
+ * June 22, 2000                                                             *
  * Programmed by: Kevin Lindsay                                              *
- * Copyright (c) 1998 Kevin Lindsay & Netnation Communications Inc.          *
+ * Copyright (c) 1999, 2000 Kevin Lindsay & Netnation Communications Inc.    *
  *                                                                           *
  * NetNation Communications   http://www.netnation.com/                      *
  * Secure Locate: ftp://ftp.mkintraweb.com/pub/linux/slocate/                *
- *                http://pep.stormix.com/slocate/                            *
  *                                                                           *
  * Patches:  Sean Mcnulty <lazy@ccf.rutgers.edu>                             *
  *                * Fixed a bug which caused the decode function to fail.    *
@@ -96,7 +95,7 @@
 
 /* GLOBALS */
 
-#define VERSION "Secure Locate v2.1 - Released October 19, 1999\n"
+#define VERSION "Secure Locate v2.2 - Released June 22, 2000\n"
 #define GRPFILE "/etc/group"
 #define SLOC_ESC 0x80
 #define SLOC_GRP "slocate"
@@ -155,7 +154,7 @@ usage()
 {
    int i;
    printf("%s\n"
-          "Copyright (c) 1999 Kevin Lindsay & Netnation Communications Inc.\n\n"
+          "Copyright (c) 1999, 2000 Kevin Lindsay & Netnation Communications Inc.\n\n"
           "search usage:   %s [-qi] [-d <path>] [--database=<path>] <search string>...\n"
           "                %s [-r <regexp>] [--regexp=<regexp>]\n"
           "database usage: %s [-qv] [-o <file>] [--output=<file>]\n"
@@ -232,10 +231,38 @@ get_short (FILE *fp)
    return (x << 8) | (fgetc (fp) & 0xff);
 }
 
+/* Validate database file */
+int
+    validate_db(char *database)
+{
+	int fd;
+	char buf[2];
+	
+	fd = open(database,O_RDONLY);
+	
+	if (fd == -1)
+	    return 0;
+	
+	if (read(fd,buf,2) < 2) {
+		close(fd);
+		return 0;
+	}
+	
+	if ((buf[0] != '1' && buf[0] != '0') ||
+	    buf[1] != 0) {
+		close(fd);
+		return 0;
+	}
+	
+	close(fd);
+	
+	return 1;
+}
+
 /* Parse Output Path */
 
 void
-parse_create_path(char *path)
+    parse_create_path(char *path)
 {
    int ret_val;
    
@@ -280,10 +307,15 @@ parse_decode_path(char *path)
    pathcopy[0] = '\0';
    strcat(pathcopy, path);
    part = strtok(pathcopy, ":");
-   while(part) {
-      SLOCATE_PATH[i++] = part;
-      part = strtok(NULL, ":");
+
+   while (part) {
+	   if (validate_db(part))
+	       SLOCATE_PATH[i++] = part;
+	   else if (!QUIET)
+	       fprintf(stderr,"%s: this is not a valid slocate database: %s\n",progname,part);
+	   part = strtok(NULL, ":");
    }
+
    SLOCATE_PATH[i] = NULL;
 }
 
@@ -984,9 +1016,9 @@ decode_db(char *database, char *str)
    lstat(database,&statres);
 
    if (S_ISDIR(statres.st_mode)) {
-   if (!QUIET)
-        fprintf(stderr,"%s: decode_db(): %s is a directory\n",progname,database);
-   return(0);
+	   if (!QUIET)
+	       fprintf(stderr,"%s: decode_db(): %s is a directory\n",progname,database);
+	   return(0);
    }
 
    time(&now);
