@@ -32,10 +32,9 @@ load_file(const char *filename) {
 	} else {
 		tmp_errno = errno;
 		res = 0;
-		fbuf = malloc(strlen(strerror(tmp_errno)+2));
-		fbuf[0] = 0;
+		fbuf = malloc(strlen(strerror(tmp_errno))+2);
+		*fbuf = 0;
 		strcat((fbuf+1),strerror(tmp_errno));
-		fbuf[strlen(strerror(tmp_errno))+1] = 0;
 	}
 	
 	return(fbuf);
